@@ -716,7 +716,7 @@ def _list_all_descendant_keys(context, key_prefix):
 @gen.coroutine
 def _list_keys(context, key_prefix, delimiter):
 
-    max_keys = '1000'
+    max_keys = 1000
 
     @gen.coroutine
     def _list_first_page():
